@@ -74,7 +74,7 @@ public:
 
     static inline KAboutData aboutData()
     {
-        KAboutData aboutData("ktp-approver", "kded_ktp_approver", KLocalizedString(), "0.5",
+        KAboutData aboutData("ktp-approver", "kded_ktp_approver", KLocalizedString(), "0.5.1",
                              KLocalizedString(), KAboutData::License_LGPL,
                              ki18nc("@info:credit", "(C) 2010, Collabora Ltd."));
         aboutData.addAuthor(ki18nc("@info:credit", "George Kiagiadakis"),
